@@ -930,7 +930,7 @@ load_bugzillas (void)
 	d(g_list_foreach (druid_data.dldests, (GFunc)p_string, NULL));
 }
 
-#define ALL_APPLICATIONS_URI "all-applications:///"
+#define ALL_APPLICATIONS_URI "applications-all-users:///"
 #define APPLET_REQUIREMENTS \
 	"has_all (repo_ids, ['IDL:Bonobo/Control:1.0'," \
 	"		     'IDL:GNOME/Vertigo/PanelAppletShell:1.0']) && " \
@@ -1003,8 +1003,10 @@ bugzilla_application_new (const char *name,
 			char *s;
 			s = strrchr (programv[0], G_DIR_SEPARATOR);
 			s = s ? s+1 : programv[0];
-			d(g_print ("adding app: %s\n", s));
-			g_hash_table_insert (druid_data.program_to_application, g_strdup (s), app);
+			if (g_hash_table_lookup (druid_data.program_to_application, s) == NULL) {
+				d(g_print ("adding app: %s\n", s));
+				g_hash_table_insert (druid_data.program_to_application, g_strdup (s), app);
+			}
 		}
 		if (programv)
 			g_strfreev (programv);
@@ -1013,8 +1015,10 @@ bugzilla_application_new (const char *name,
 	if (other_programs) {
 		programv = g_strsplit (other_programs, ";", -1);
 		for (i=0; programv[i]; i++) {
-			d(g_print ("adding app: %s\n", programv[i]));
-			g_hash_table_insert (druid_data.program_to_application, g_strdup (programv[i]), app);
+			if (g_hash_table_lookup (druid_data.program_to_application, programv[i]) == NULL) {
+				d(g_print ("adding app: %s\n", programv[i]));
+				g_hash_table_insert (druid_data.program_to_application, g_strdup (programv[i]), app);
+			}
 		}
 		g_strfreev (programv);
 	}
@@ -1088,6 +1092,18 @@ visit_cb (const char *rel_path,
 	GError *error = NULL;
 	char *full_path, *icon;
 	GnomeIconTheme *git = data;
+	
+	if (info->name[0] != '.'
+	    || (info->name[1] != '.' && info->name[1] != 0)
+	    || info->name[2] != 0) {
+		if (recursing_will_loop) {
+			g_print ("Loop detected\n");
+			return TRUE;
+		}
+		*recurse = TRUE;
+	} else {
+		*recurse = FALSE;
+	}
 
 	full_path = g_strconcat (ALL_APPLICATIONS_URI, rel_path, NULL);
 
@@ -1383,7 +1399,9 @@ generate_email_text (gboolean include_headers)
 	GString *email;
 	char *subject, *body, *s, *debug_info, *version, *severity;
 
-	gboolean is_bugzilla = !GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active;
+	gboolean is_bugzilla;
+       
+	is_bugzilla = !(GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active || druid_data.product == NULL);
 
 	email = g_string_new (NULL);
 
